%global github_owner    splunk
%global github_name     pion
%global github_version  5.0.7
%global github_commit   2b16caeedc9b0ffd275867b157305c333c0f118d

%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}}
%{!?_licensedir:%global license %%doc}

# This should really be called pion, but I'm just a drive-by proven
# packager and I don't want to go through a rename review. -adamw
Name:		pion-net
Version:	5.0.7
Release:	1%{?dist}
Summary:	C++ library for building lightweight HTTP interfaces

License:	Boost
URL:		https://github.com/%{github_owner}/%{github_name}
# Must use commit-based not tag-based github tarball:
# https://fedoraproject.org/wiki/Packaging:SourceURL#Github
Source0:	https://github.com/%{github_owner}/%{github_name}/archive/%{github_commit}/%{github_name}-%{github_version}.tar.gz

BuildRequires:	boost-devel >= 1.35.0, openssl-devel, log4cplus-devel, zlib-devel, bzip2-devel, libicu-devel
BuildRequires:	doxygen, autoconf, automake, libtool

Patch0:		pion-net-cflags.patch
Patch1:		pion-net-pkgconfig.patch

%description
Pion Network Library is a C++ framework for building lightweight HTTP
interfaces.

%package	devel
Summary:	Development files for pion-net
Requires:	%{name}%{?_isa} = %{version}-%{release}
Requires:	boost-devel >= 1.35.0, openssl-devel, log4cplus-devel, zlib-devel, bzip2-devel, libicu-devel

%description devel
This package contains the pkgconfig, header files, and libraries needed to
develop application that use pion-net.

%package	doc
Summary:	Documentation for pion-net
BuildArch:	noarch

%description doc
This package contains Doxygen HTML documentation for pion-net library.


%prep
%setup -q -n %{github_name}-%{github_commit}
for patch in %patches; do
	echo "Applying $patch" >&2
	%__patch -p1 -i $patch
done


%build

./autogen.sh
%configure \
	--disable-static \
	--with-pic \
	--with-plugins=%{_libdir}/pion/plugins \
	--with-zlib \
	--with-bzlib \
	--with-openssl \
	--with-log4cplus

make %{?_smp_mflags}

# regenerate upstream documentation
make doxygen-clean
make doxygen-run

%install
make install DESTDIR=%{buildroot}

# delete example apps
rm -f %{buildroot}%{_bindir}/helloserver
rm -f %{buildroot}%{_bindir}/piond

# delete libtool archives
rm -f %{buildroot}%{_libdir}/*.la
rm -f %{buildroot}%{_libdir}/pion/plugins/*.la

# install documentation
install -d -m 0755 %{buildroot}%{_pkgdocdir}
cp -arv doc/html %{buildroot}%{_pkgdocdir}/html


%check
make check


%post -p /sbin/ldconfig


%postun -p /sbin/ldconfig


%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README.md TODO

%dir %{_libdir}/pion
%dir %{_libdir}/pion/plugins
%{_libdir}/libpion-*.so
%{_libdir}/pion/plugins/*.so
%exclude %{_pkgdocdir}/html


%files devel
%{_includedir}/pion/
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libpion.so


%files doc
%doc %{_pkgdocdir}/html


%changelog
* Tue Jul 28 2015 Adam Williamson <awilliam@redhat.com> - 5.0.7-1
- new release 5.0.7
- rediff still-relevant patches, drop those now irrelevant

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 4.0.9-19
- rebuild for Boost 1.58

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.9-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 4.0.9-17
- Rebuilt for GCC 5 C++11 ABI change

* Tue Jan 27 2015 Petr Machata <pmachata@redhat.com> - 4.0.9-16
- Rebuild for boost 1.57.0

* Tue Aug 26 2014 David Tardon <dtardon@redhat.com> - 4.0.9-15
- rebuild for ICU 53.1

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.9-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.9-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 Petr Machata <pmachata@redhat.com> - 4.0.9-12
- Rebuild for boost 1.55.0

* Fri Feb 14 2014 David Tardon <dtardon@redhat.com> - 4.0.9-11
- rebuild for new ICU

* Fri Nov 15 2013 Jan Vcelak <jvcelak@fedoraproject.org> 4.0.9-10
- rebuild due to broken dependencies

* Sun Sep 01 2013 Jan Vcelak <jvcelak@fedoraproject.org> 4.0.9-9
- rebuild due to broken dependencies
- update for unversioned doc directory feature

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.9-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Jul 27 2013 Petr Machata <pmachata@redhat.com> - 4.0.9-7
- Rebuild for boost 1.54.0
- Drop --with-boost-extension=-mt, Boost doesn't use tagged layout
  anymore

* Sun Feb 10 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 4.0.9-6
- Rebuild for Boost-1.53.0

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 4.0.9-5
- Rebuild for Boost-1.53.0

* Sat Jan 26 2013 Kevin Fenzi <kevin@scrye.com> - 4.0.9-4
- Rebuild for new icu
- Simplify patch loop so it works with current rpm

* Thu Aug 16 2012 Jan Vcelak <jvcelak@redhat.com> 4.0.9-3
- rebuild with new boost library

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.9-2
- Rebuilt for c++ ABI breakage

* Thu Feb 02 2012 Jan Vcelak <jvcelak@redhat.com> 4.0.9-1
- rebase to new upstream version
  + HTTPReader - add support for timeouts (900)

* Mon Nov 28 2011 Jan Vcelak <jvcelak@redhat.com> 4.0.7-4
- fix Source URL to include version tag
- remove bzlib2 and zlib dependencies (no reference in source code)

* Wed Nov 23 2011 Jan Vcelak <jvcelak@redhat.com> 4.0.7-3
- remove documentation from the base package
- fix typo in configure option (--with-pic)
- remove libicu-devel from BuildRequires
- fix automake not to replace Fedora compiler flags
- migrate the library to use Boost Filesystem version 3
- add -devel package Requires
- move unversioned .so files to -devel package

* Tue Nov 22 2011 Jan Vcelak <jvcelak@redhat.com> 4.0.7-2
- change Summary to be more eglible
- do not explicitly clean buildroot before installation
- include orphaned directories
- fix -devel package requirements
- fix -doc package requirements

* Tue Nov 15 2011 Jan Vcelak <jvcelak@redhat.com> 4.0.7-1
- initial package for Fedora
